@@ -1,7 +1,15 @@
-import md5
-
+try:
+    import hashlib
+    m = hashlib.md5()
+except ImportError:
+    # for Python << 2.5
+    import md5
+    m = md5.new()
+    
 from django import template
+from django.conf import settings
 
+MEDIAHASH_INACTIVE = getattr(settings, 'MEDIAHASH_INACTIVE', settings.DEBUG)
 register = template.Library()
 
 @register.simple_tag
@@ -9,15 +17,9 @@ def mediahash(name):
 	return dohash(name)
 
 def dohash(name):
-	from django.conf import settings
-	if settings.DEBUG:
+	if MEDIAHASH_INACTIVE:
 		return "%s/%s" % (settings.MEDIA_URL, name)
 	else:
-		try:
-			from django.conf import settings
-		except ImportError:
-			return ''
-		m = md5.new()
 		m.update(name)
 		h = m.hexdigest()
 		number = int(h, 16) % settings.MEDIA_HASH_RANGE + 1
